create_heatmap

create_heatmap(explor, sa, sb)

Arguments

explor

the explor tibble to construct the heatmap out of

sa

the first set of terms to compare

sb

the second set of terms to compare

Value

a ggplot plot showing a heatmap correlation between the sets