example_explor_b.RdA dataset containing a fully formed term search set, English translations, and eric article counts
example_explor_bA tibble with four search terms, queries, eric counts, and proquest counts. NA represents data has not been collected
search term "A"
search term "B"
search term "C"
search term "D"
English translation of search query
Number of matching articles in ERIC
Number of matching articles in Proquest