create_heatmap.Rd
create_heatmap
create_heatmap(explor, sa, sb)
the explor tibble to construct the heatmap out of
the first set of terms to compare
the second set of terms to compare
a ggplot plot showing a heatmap correlation between the sets