get_proquest_count.Rdget_proquest_count
get_proquest_count(
terms,
database = "medlineprof",
authorization = "Bearer 8461684a-5a79-407c-9321-93d8d719ddeb"
)terms to search for
proquest has lots of databases, which one are we after?
our bearer token for access
an integer with the corresponding number of articles proquest has for the search